# -*- coding: utf-8 -*-

# Copyright (c) 2008 - 2020 Kyoto University and Honda Motor Co.,Ltd.
# All rights reserved.
# HARK was developed by researchers in Okuno Laboratory
# at the Kyoto University and Honda Research Institute Japan Co.,Ltd.
# 
# Licensed under the HARK license, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
# https://www.hark.jp/notice/HARK_License_Agreement.pdf

import numpy
from matplotlib import pyplot
from harkpython import harkbasenode

class HarkNode(harkbasenode.HarkBaseNode):
    def __init__(self):
        self.outputNames = ("OUTPUT",)
        self.outputTypes = ("prim_int",)

        self.countdown = 10
        #self.isFirst = True
        self.im = None
        self.cb = None
        self.spectrum = []
        self.winlen = 100
        pyplot.ion()
        #pyplot.hold(False)

    def calculate(self):
        self.outputValues["OUTPUT"] = 0
        tmp = numpy.array(self.SPECTRUM)
        if(numpy.sum(tmp) == 0):
            return;
        self.spectrum.append(tmp)
        self.countdown -= 1

        if self.countdown == 0:
            self.countdown = 10
            if len(self.spectrum) > self.winlen:
                self.spectrum = self.spectrum[len(self.spectrum)-self.winlen:]
            arr = numpy.flipud(numpy.array(self.spectrum).transpose())
            if self.im is None:
                pyplot.clf()
                self.im = pyplot.imshow(arr, aspect="auto", interpolation="nearest")
                self.cb = pyplot.colorbar()
                pyplot.xlim([0, self.winlen])
                pyplot.xlabel("Time")
                pyplot.ylabel("Azimuth")
            else:
                self.im.set_array(arr)
                ext = self.im.get_extent()
                self.im.set_extent((ext[0], arr.shape[1], ext[2], ext[3]))
                self.cb.set_clim(vmin=arr.min(), vmax=arr.max())
                self.cb.draw_all()
            pyplot.pause(0.01)
        

