# -*- coding: utf-8 -*-

# Copyright (c) 2008 - 2020 Kyoto University and Honda Motor Co.,Ltd.
# All rights reserved.
# HARK was developed by researchers in Okuno Laboratory
# at the Kyoto University and Honda Research Institute Japan Co.,Ltd.
# 
# Licensed under the HARK license, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
# https://www.hark.jp/notice/HARK_License_Agreement.pdf

import pyqtgraph as pg
from pyqtgraph.Qt import QtGui
import numpy
from harkpython import harkbasenode

class HarkNode(harkbasenode.HarkBaseNode):
    def __init__(self):
        self.outputNames = ("OUTPUT",)
        self.outputTypes = ("prim_int",)

        self.spectrum = numpy.array([])
        self.winlen = 100
        self.app = QtGui.QApplication([])
        # self.app.quitOnLastWindowClosed()

        self.main = QtGui.QMainWindow()
        self.main.setWindowTitle("HARK Python MUSIC Spectrogram")
        self.main.resize(800, 200)

        self.cwidget = QtGui.QWidget()
        self.main.setCentralWidget(self.cwidget)
        self.layout = QtGui.QVBoxLayout()
        self.cwidget.setLayout(self.layout)

        self.swidget = pg.ImageView()
        self.layout.addWidget(self.swidget)

        self.main.show()

    def calculate(self):
        self.outputValues["OUTPUT"] = 0
        tmp = numpy.array(self.SPECTRUM)[numpy.newaxis, :]
        if tmp.sum() == 0:
            return

        if len(self.spectrum) == 0:
            self.spectrum = tmp
        else:
            self.spectrum = numpy.r_[self.spectrum, tmp]

        if len(self.spectrum) > self.winlen:
            self.spectrum = self.spectrum[len(self.spectrum)-self.winlen:]

        self.swidget.setImage(self.spectrum)
        QtGui.QApplication.processEvents()

