# -*- coding: utf-8 -*-

# Copyright (c) 2008 - 2020 Kyoto University and Honda Motor Co.,Ltd.
# All rights reserved.
# HARK was developed by researchers in Okuno Laboratory
# at the Kyoto University and Honda Research Institute Japan Co.,Ltd.
# 
# Licensed under the HARK license, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
# https://www.hark.jp/notice/HARK_License_Agreement.pdf

import pyqtgraph as pg
from pyqtgraph.Qt import QtGui
import numpy
from harkpython import harkbasenode


class HarkNode(harkbasenode.HarkBaseNode):
    def __init__(self):
        self.outputNames = ("OUTPUT",)
        self.outputTypes = ("prim_int",)

        self.specgram = []
        self.winlen = 600

        self.app = QtGui.QApplication([])
        self.app.quitOnLastWindowClosed()

        self.main = QtGui.QMainWindow()
        self.main.setWindowTitle("HARK Python Spectrogram")
        self.main.resize(800, 200)

        self.cwidget = QtGui.QWidget()
        self.main.setCentralWidget(self.cwidget)
        self.layout = QtGui.QVBoxLayout()
        self.cwidget.setLayout(self.layout)

        self.swidgets = []
        self.main.show()

    def calculate(self):
        if self.count == 0:
            # make widgets
            # for i in range(self.FFT.shape[0]):
            for i in range(1):
                self.swidgets.append(pg.ImageView())
                self.layout.addWidget(self.swidgets[i])
                self.specgram.append(numpy.array([]))

        # construct spectrum data
        for i in range(len(self.specgram)):
            tmp = 20 * numpy.log10(numpy.array(numpy.abs(self.FFT[i][:])) + 1)[numpy.newaxis, :]

            if len(self.specgram[i]) == 0:
                self.specgram[i] = tmp
            else:
                self.specgram[i] = numpy.r_[self.specgram[i], tmp]

            if len(self.specgram[i]) > self.winlen:
                self.specgram[i] = self.specgram[i][len(self.specgram[i])-self.winlen:]

        # update spectrogram
        if self.count % 10 == 0:
            for i in range(len(self.specgram)):
                arr = numpy.fliplr(numpy.array(self.specgram[i]))
                self.swidgets[i].setImage(arr)
            QtGui.QApplication.processEvents()

        self.outputValues["OUTPUT"] = 0
