# -*- coding: utf-8 -*-

# Copyright (c) 2008 - 2020 Kyoto University and Honda Motor Co.,Ltd.
# All rights reserved.
# HARK was developed by researchers in Okuno Laboratory
# at the Kyoto University and Honda Research Institute Japan Co.,Ltd.
# 
# Licensed under the HARK license, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
# https://www.hark.jp/notice/HARK_License_Agreement.pdf

import numpy
from matplotlib import pyplot
from harkpython import harkbasenode


def cartesian2polar(xyz):
    """cartesian2polar(x, y, z)
converts coordinate from xyz to r\theta\phi"""
    x, y, z = xyz
    if z == 0:
        raise exceptions.ValueError(
            "cartesian " + str(xyz) + " z must be nonzero.")

    r = numpy.sqrt(sum(map(lambda x: x**2, [x, y, z])))
    theta = numpy.arccos(z/r)
    phi = numpy.arccos(x / numpy.sqrt(sum(map(lambda x: x**2, [x, y]))))
    if y < 0:
        phi *= -1

    return (r, theta, phi)


def r2d(r):
    return 180.0 / numpy.pi * r


class HarkNode(harkbasenode.HarkBaseNode):
    def __init__(self):
        self.outputNames = ("OUTPUT", )
        self.outputTypes = ("prim_int",)

        pyplot.ion()
        self.plotx = {}
        self.ploty = {}
        self.winlen = 300

    def calculate(self):
        for src in self.SOURCES:
            if "x" in src.keys():
                self.plotx.setdefault(src["id"], [])
                self.ploty.setdefault(src["id"], [])
                self.plotx[src["id"]].append(self.count)
                self.ploty[src["id"]].append(r2d(cartesian2polar(src["x"])[2]))

        if self.count % 10 == 0:
            for i, srcid in enumerate(self.plotx.keys()):
                if i == 0:
                    pyplot.clf()
                #if i == 0:
                #    pyplot.hold(False)
                #else:
                #    pyplot.hold(True)
                pyplot.plot(self.plotx[srcid],
                           self.ploty[srcid], "." + "rgb"[srcid % 3])
            pyplot.xlim([self.count-self.winlen, self.count])
            pyplot.ylim([-180, 180])
            pyplot.xlabel("Time [frame]")
            pyplot.ylabel("Azimuth [deg]")
            pyplot.pause(0.01)

        self.outputValues["OUTPUT"] = 0

#    def __del__(self):
#        pyplot.close()
