# -*- coding: utf-8 -*-

# Copyright (c) 2008 - 2020 Kyoto University and Honda Motor Co.,Ltd.
# All rights reserved.
# HARK was developed by researchers in Okuno Laboratory
# at the Kyoto University and Honda Research Institute Japan Co.,Ltd.
# 
# Licensed under the HARK license, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
# https://www.hark.jp/notice/HARK_License_Agreement.pdf

import numpy
from matplotlib import pyplot
from harkpython import harkbasenode


class HarkNode(harkbasenode.HarkBaseNode):
    def __init__(self):
        self.outputNames = ("OUTPUT",)
        self.outputTypes = ("prim_int",)

        self.isFirst = True
        self.specgram = []
        self.winlen = 300
        pyplot.ion()
        #pyplot.hold(False)

    def calculate(self):
        self.FFT = numpy.array(self.FFT)
        self.specgram.append(abs(self.FFT[0, :]))

        if self.count % 50 == 0:
            if len(self.specgram) > self.winlen:
                self.specgram = self.specgram[len(self.specgram)-self.winlen:]

            pyplot.clf()
            pyplot.imshow(numpy.flipud(numpy.array(self.specgram).transpose()))

            if self.isFirst:
                pyplot.colorbar()
                self.isFirst = False
            pyplot.xlim([0, self.winlen])
            pyplot.xticks(range(0, self.winlen, 50),
                         range(self.count - self.winlen, self.count, 50))
            pyplot.xlabel("Time [frame]")
            pyplot.ylabel("Frequency bin")
            pyplot.pause(0.01)

        self.outputValues["OUTPUT"] = 0

#    def __del__(self):
#        pyplot.close()
